@@ -92,7 +92,9 @@ class EnvDBResource(object):
                 "state":node[4],
                 "system":node[3],
                 "description":node[7],
-                "port": node[14]
+                "port": node[14],
+                "update_time": node[15],
+                "platform": node[13]
             }
             node_list.append(node_item)
         return node_list
